==> brlcad-7.24.2.tar.bz2: brlcad-7.24.2/src/conv/step/step-g/ShapeRepresentationRelationship.h <==
/*                 ShapeRepresentationRelationship.h
 * BRL-CAD
 *
 * Copyright (c) 1994-2013 United States Government as represented by
 * the U.S. Army Research Laboratory.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this file; see the file named COPYING for more
 * information.
 */
/** @file step/ShapeRepresentationRelationship.h
 *
 * Class definition used to convert STEP "ShapeRepresentationRelationship" to BRL-CAD BREP
 * structures.
 *
 */

#ifndef SHAPE_REPRESENTATION_RELATIONSHIP_H_
#define SHAPE_REPRESENTATION_RELATIONSHIP_H_

#include "STEPEntity.h"

#include "sdai.h"

#include "RepresentationRelationship.h"
// forward declaration of class
class ON_Brep;

class ShapeRepresentationRelationship: public RepresentationRelationship
{
private:
    static string entityname;
    static EntityInstanceFunc GetInstance;

protected:

public:
    ShapeRepresentationRelationship();
    virtual ~ShapeRepresentationRelationship();
    ShapeRepresentationRelationship(STEPWrapper *sw, int step_id);
    bool Load(STEPWrapper *sw, SDAI_Application_instance *sse);
    virtual bool LoadONBrep(ON_Brep *brep);
    string ClassName();
    virtual void Print(int level);

    //static methods
    static STEPEntity *Create(STEPWrapper *sw, SDAI_Application_instance *sse);
};

#endif /* SHAPE_REPRESENTATION_RELATIONSHIP_H_ */

/*
 * Local Variables:
 * tab-width: 8
 * mode: C
 * indent-tabs-mode: t
 * c-file-style: "stroustrup"
 * End:
 * ex: shiftwidth=4 tabstop=8
 */

==> brlcad-7.32.4.tar.bz2: brlcad-7.32.4/src/conv/step/step-g/ShapeRepresentationRelationship.h <==
/*                 ShapeRepresentationRelationship.h
 * BRL-CAD
 *
 * Copyright (c) 1994-2021 United States Government as represented by
 * the U.S. Army Research Laboratory.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this file; see the file named COPYING for more
 * information.
 */
/** @file step/ShapeRepresentationRelationship.h
 *
 * Class definition used to convert STEP "ShapeRepresentationRelationship" to BRL-CAD BREP
 * structures.
 *
 */

#ifndef CONV_STEP_STEP_G_SHAPEREPRESENTATIONRELATIONSHIP_H
#define CONV_STEP_STEP_G_SHAPEREPRESENTATIONRELATIONSHIP_H

#include "STEPEntity.h"

#include "sdai.h"

#include "RepresentationRelationship.h"
// forward declaration of class
class ON_Brep;

class ShapeRepresentationRelationship: public RepresentationRelationship
{
private:
    static string entityname;
    static EntityInstanceFunc GetInstance;

protected:

public:
    ShapeRepresentationRelationship();
    virtual ~ShapeRepresentationRelationship();
    ShapeRepresentationRelationship(STEPWrapper *sw, int step_id);
    bool Load(STEPWrapper *sw, SDAI_Application_instance *sse);
    virtual bool LoadONBrep(ON_Brep *brep);
    string ClassName();
    virtual void Print(int level);

    //static methods
    static STEPEntity *Create(STEPWrapper *sw, SDAI_Application_instance *sse);
};

#endif /* CONV_STEP_STEP_G_SHAPEREPRESENTATIONRELATIONSHIP_H */

/*
 * Local Variables:
 * tab-width: 8
 * mode: C
 * indent-tabs-mode: t
 * c-file-style: "stroustrup"
 * End:
 * ex: shiftwidth=4 tabstop=8
 */
